Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(94)

Unified Diff: tools/dom/scripts/generator.py

Issue 14426006: Rename dart:typeddata to dart:typed_data. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/create_sdk.py ('k') | tools/dom/scripts/htmlrenamer.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/dom/scripts/generator.py
diff --git a/tools/dom/scripts/generator.py b/tools/dom/scripts/generator.py
index c5a8649ab4f36de3f495c47d2797aa950843177a..6163f5347266fbb25f98002d7d43ce88a0664e19 100644
--- a/tools/dom/scripts/generator.py
+++ b/tools/dom/scripts/generator.py
@@ -385,7 +385,7 @@ class OperationInfo(object):
else:
# TODO(antonm): temporary ugly hack.
# While in transition phase we allow both DOM's ArrayBuffer
# and dart:typeddata's ByteBuffer for IDLs' ArrayBuffers,
# hence ArrayBuffer is mapped to dynamic in arguments and return
# values. To compensate for that when generating ArrayBuffer itself,
# we need to lie a bit:
@@ -1379,7 +1379,7 @@ class TypeData(object):
def TypedListTypeData(item_type):
return TypeData(
clazz='TypedList',
- dart_type='List<%s>' % item_type, # TODO(antonm): proper typeddata interfaces.
+ dart_type='List<%s>' % item_type, # TODO(antonm): proper typed_data interfaces.
item_type=item_type,
is_typed_array=True)
« no previous file with comments | « tools/create_sdk.py ('k') | tools/dom/scripts/htmlrenamer.py » ('j') | no next file with comments »
@@ -385,7 +385,7 @@ class OperationInfo(object):
# TODO(antonm): temporary ugly hack.
# While in transition phase we allow both DOM's ArrayBuffer
- # and dart:typeddata's ByteBuffer for IDLs' ArrayBuffers,
+ # and dart:typed_data's ByteBuffer for IDLs' ArrayBuffers,
# hence ArrayBuffer is mapped to dynamic in arguments and return
# values. To compensate for that when generating ArrayBuffer itself,

Powered by Google App Engine
This is Rietveld 408576698